@@ -255,24 +255,12 @@ swap_ranges(_ExecutionPolicy&& __exec, _Range1&& __rng1, _Range2&& __rng2)
     using _ReferenceType1 = oneapi::dpl::__internal::__value_t<_Range1>&;
     using _ReferenceType2 = oneapi::dpl::__internal::__value_t<_Range2>&;
 
-    auto __v1 = views::all(::std::forward<_Range1>(__rng1));
-    auto __v2 = views::all(::std::forward<_Range2>(__rng2));
-    const auto is_first_size = __v1.size() <= __v2.size();
-
-    auto __f = [](_ReferenceType1 __x, _ReferenceType2 __y) {
-        using ::std::swap;
-        swap(__x, __y);
-    };
-
-    if (is_first_size)
-    {
-        oneapi::dpl::__internal::__ranges::__pattern_walk_n<1>(::std::forward<_ExecutionPolicy>(__exec), __f, __v1,
-                                                               __v2);
-        return __v1.size();
-    }
-
-    oneapi::dpl::__internal::__ranges::__pattern_walk_n<2>(::std::forward<_ExecutionPolicy>(__exec), __f, __v2, __v1);
-    return __v2.size();
+    return oneapi::dpl::__internal::__ranges::__pattern_swap(
+        ::std::forward<_ExecutionPolicy>(__exec), views::all(::std::forward<_Range1>(__rng1)),
+        views::all(::std::forward<_Range2>(__rng2)), [](_ReferenceType1 __x, _ReferenceType2 __y) {
+            using ::std::swap;
+            swap(__x, __y);
+        });
 }
 
 // [alg.transform]
