@@ -315,7 +315,7 @@ __radix_sort_count_submit(_ExecutionPolicy&& __exec, ::std::size_t __segments, :
         oneapi::dpl::__ranges::__require_access(__hdl, __val_rng,
                                                 __count_rng); //get an access to data under SYCL buffer
         // an accessor per work-group with value counters from each work-item
-        auto __count_lacc = sycl::accessor<_CountT, 1, access_mode::read_write, access_target::local>(
+        auto __count_lacc = sycl::accessor<_CountT, 1, access_mode::read_write, __dpl_sycl::__target::local>(
             __block_size * __radix_states, __hdl);
 #if _ONEDPL_COMPILE_KERNEL && _ONEDPL_KERNEL_BUNDLE_PRESENT
         __hdl.use_kernel_bundle(__kernel.get_kernel_bundle());
@@ -625,12 +625,11 @@ __parallel_radix_sort_iteration(_ExecutionPolicy&& __exec, ::std::size_t __segme
 
     // correct __block_size, __scan_wg_size, __reorder_sg_size after introspection of the kernels
 #if _ONEDPL_COMPILE_KERNEL
-    auto __count_kernel =
-        __internal::__kernel_compiler<_RadixCountKernel>::__compile_kernel(::std::forward<_ExecutionPolicy>(__exec));
-    auto __local_scan_kernel = __internal::__kernel_compiler<_RadixLocalScanKernel>::__compile_kernel(
-        ::std::forward<_ExecutionPolicy>(__exec));
-    auto __reorder_kernel =
-        __internal::__kernel_compiler<_RadixReorderKernel>::__compile_kernel(::std::forward<_ExecutionPolicy>(__exec));
+    auto __kernels =
+        __internal::__kernel_compiler<_RadixCountKernel, _RadixLocalScanKernel, _RadixReorderKernel>::__compile(__exec);
+    auto __count_kernel = __kernels[0];
+    auto __local_scan_kernel = __kernels[1];
+    auto __reorder_kernel = __kernels[2];
     ::std::size_t __count_sg_size = oneapi::dpl::__internal::__kernel_sub_group_size(__exec, __count_kernel);
     __reorder_sg_size = oneapi::dpl::__internal::__kernel_sub_group_size(__exec, __reorder_kernel);
     __scan_wg_size =
@@ -641,8 +640,7 @@ __parallel_radix_sort_iteration(_ExecutionPolicy&& __exec, ::std::size_t __segme
 
     // correct __block_size according to local memory limit in count phase
     const auto __max_allocation_size = oneapi::dpl::__internal::__max_local_allocation_size(
-        ::std::forward<_ExecutionPolicy>(__exec), sizeof(typename __decay_t<_TmpBuf>::value_type),
-        __block_size * __radix_states);
+        __exec, sizeof(typename __decay_t<_TmpBuf>::value_type), __block_size * __radix_states);
     __block_size = __get_roundedup_div(__max_allocation_size, __radix_states);
 
     // TODO: block size must be power of 2 and more than number of states. Check how to get rid of that restriction.
@@ -652,8 +650,8 @@ __parallel_radix_sort_iteration(_ExecutionPolicy&& __exec, ::std::size_t __segme
 
     // 1. Count Phase
     sycl::event __count_event = __radix_sort_count_submit<_RadixCountKernel, __radix_bits, __is_comp_asc>(
-        ::std::forward<_ExecutionPolicy>(__exec), __segments, __block_size, __radix_iter,
-        ::std::forward<_InRange>(__in_rng), __tmp_buf, __dependency_event
+        __exec, __segments, __block_size, __radix_iter, ::std::forward<_InRange>(__in_rng), __tmp_buf,
+        __dependency_event
 #if _ONEDPL_COMPILE_KERNEL
         ,
         __count_kernel
@@ -663,7 +661,7 @@ __parallel_radix_sort_iteration(_ExecutionPolicy&& __exec, ::std::size_t __segme
     // 2. Scan Phase
     sycl::event __scan_event =
         __radix_sort_scan_submitter<_RadixLocalScanKernel, _RadixGlobalScanKernel, __radix_bits>()(
-            ::std::forward<_ExecutionPolicy>(__exec), __scan_wg_size, __segments, __tmp_buf, __count_event
+            __exec, __scan_wg_size, __segments, __tmp_buf, __count_event
 #if _ONEDPL_COMPILE_KERNEL
             ,
             __local_scan_kernel
@@ -672,8 +670,8 @@ __parallel_radix_sort_iteration(_ExecutionPolicy&& __exec, ::std::size_t __segme
 
     // 3. Reorder Phase
     sycl::event __reorder_event = __radix_sort_reorder_submit<_RadixReorderKernel, __radix_bits, __is_comp_asc>(
-        ::std::forward<_ExecutionPolicy>(__exec), __segments, __block_size, __reorder_sg_size, __radix_iter,
-        ::std::forward<_InRange>(__in_rng), ::std::forward<_OutRange>(__out_rng), __tmp_buf, __scan_event
+        __exec, __segments, __block_size, __reorder_sg_size, __radix_iter, ::std::forward<_InRange>(__in_rng),
+        ::std::forward<_OutRange>(__out_rng), __tmp_buf, __scan_event
 #if _ONEDPL_COMPILE_KERNEL
         ,
         __reorder_kernel
@@ -688,7 +686,7 @@ __parallel_radix_sort_iteration(_ExecutionPolicy&& __exec, ::std::size_t __segme
 //-----------------------------------------------------------------------
 
 template <bool __is_comp_asc, typename _Range, typename _ExecutionPolicy>
-__future<void>
+auto
 __parallel_radix_sort(_ExecutionPolicy&& __exec, _Range&& __in_rng)
 {
     const ::std::size_t __n = __in_rng.size();
@@ -736,7 +734,7 @@ __parallel_radix_sort(_ExecutionPolicy&& __exec, _Range&& __in_rng)
         explicit_wait_if<::std::is_pointer<decltype(__in_rng.begin())>::value>{}(__iteration_event);
     }
 
-    return __future<void>(__iteration_event, __tmp_buf, __out_buffer_holder.get_buffer());
+    return __future(__iteration_event, __tmp_buf, __out_buffer_holder.get_buffer());
 }
 
 } // namespace __par_backend_hetero
