@@ -35,13 +35,58 @@ using void_type = typename ::std::enable_if<::std::is_void<_Tp>::value, _Tp>::ty
 template <typename _Tp>
 using non_void_type = typename ::std::enable_if<!::std::is_void<_Tp>::value, _Tp>::type;
 
+#if _USE_GROUP_ALGOS && _ONEDPL_SYCL_INTEL_COMPILER
+//This optimization depends on Intel(R) oneAPI DPC++ Compiler implementation such as support of binary operators from std namespace.
+//We need to use _ONEDPL_SYCL_INTEL_COMPILER macro as a guard.
+
+//TODO: To change __has_known_identity implementation as soon as the Intel(R) oneAPI DPC++ Compiler implementation issues related to
+//std::multiplies, std::bit_or, std::bit_and and std::bit_xor operations will be fixed.
+//std::logical_and and std::logical_or are not supported in Intel(R) oneAPI DPC++ Compiler to be used in sycl::inclusive_scan_over_group and sycl::reduce_over_group
+template <typename _BinaryOp, typename _Tp>
+using __has_known_identity =
+#    if __LIBSYCL_VERSION >= 50200
+    typename ::std::conjunction<
+        ::std::is_arithmetic<_Tp>, __dpl_sycl::__has_known_identity<_BinaryOp, _Tp>,
+        ::std::disjunction<::std::is_same<typename ::std::decay<_BinaryOp>::type, ::std::plus<_Tp>>,
+                           ::std::is_same<typename ::std::decay<_BinaryOp>::type, __dpl_sycl::__plus<_Tp>>,
+                           ::std::is_same<typename ::std::decay<_BinaryOp>::type, __dpl_sycl::__minimum<_Tp>>,
+                           ::std::is_same<typename ::std::decay<_BinaryOp>::type, __dpl_sycl::__maximum<_Tp>>>>;
+#    else  //__LIBSYCL_VERSION >= 50200
+    typename ::std::conjunction<
+        ::std::is_arithmetic<_Tp>,
+        ::std::disjunction<::std::is_same<typename ::std::decay<_BinaryOp>::type, ::std::plus<_Tp>>,
+                           ::std::is_same<typename ::std::decay<_BinaryOp>::type, __dpl_sycl::__plus<_Tp>>>>;
+#    endif //__LIBSYCL_VERSION >= 50200
+
+#else //_USE_GROUP_ALGOS && _ONEDPL_SYCL_INTEL_COMPILER
+
+template <typename _BinaryOp, typename _Tp>
+using __has_known_identity = std::false_type;
+
+#endif //_USE_GROUP_ALGOS && _ONEDPL_SYCL_INTEL_COMPILER
+
+template <typename _BinaryOp, typename _Tp>
+struct __known_identity_for_plus
+{
+    static_assert(std::is_same_v<typename std::decay<_BinaryOp>::type, std::plus<_Tp>>);
+    static constexpr _Tp value = 0;
+};
+
+template <typename _BinaryOp, typename _Tp>
+inline constexpr _Tp __known_identity =
+#if __LIBSYCL_VERSION >= 50200
+    __dpl_sycl::__known_identity<_BinaryOp, _Tp>::value;
+#else  //__LIBSYCL_VERSION >= 50200
+    __known_identity_for_plus<_BinaryOp, _Tp>::value; //for plus only
+#endif //__LIBSYCL_VERSION >= 50200
+
 // a way to get value_type from both accessors and USM that is needed for transform_init
 template <typename _Unknown>
 struct __accessor_traits_impl
 {
 };
 
-template <typename _T, int _Dim, sycl::access::mode _AccMode, sycl::access::target _AccTarget,
+template <typename _T, int _Dim, sycl::access::mode _AccMode, __dpl_sycl::__target _AccTarget,
           sycl::access::placeholder _Placeholder>
 struct __accessor_traits_impl<sycl::accessor<_T, _Dim, _AccMode, _AccTarget, _Placeholder>>
 {
@@ -109,6 +154,54 @@ struct walk_adjacent_difference
     }
 };
 
+// the C++ stuff types to distinct "init vs. no init"
+template <typename _InitType>
+struct __init_value
+{
+    _InitType __value;
+    using __value_type = _InitType;
+};
+
+template <typename _InitType = void>
+struct __no_init_value
+{
+    using __value_type = _InitType;
+};
+
+// structure for the correct processing of the initial scan element
+template <typename _InitType>
+struct __init_processing
+{
+    template <typename _Tp>
+    void
+    operator()(const __init_value<_InitType>& __init, _Tp&& __value) const
+    {
+        __value = __init.__value;
+    }
+    template <typename _Tp>
+    void
+    operator()(const __no_init_value<_InitType>&, _Tp&&) const
+    {
+    }
+
+    template <typename _Tp, typename _BinaryOp>
+    void
+    operator()(const __init_value<_InitType>& __init, _Tp&& __value, _BinaryOp __bin_op) const
+    {
+        __value = __bin_op(__init.__value, __value);
+    }
+    template <typename _Tp, typename _BinaryOp>
+    void
+    operator()(const __no_init_value<_InitType>&, _Tp&&, _BinaryOp) const
+    {
+    }
+    template <typename _Tp, typename _BinaryOp>
+    void
+    operator()(const __no_init_value<void>&, _Tp&&, _BinaryOp) const
+    {
+    }
+};
+
 //------------------------------------------------------------------------
 // transform_reduce
 //------------------------------------------------------------------------
@@ -148,9 +241,26 @@ struct reduce
 {
     _BinaryOperation1 __bin_op1;
 
+    // Reduce on local memory with subgroups
     template <typename _NDItemId, typename _GlobalIdx, typename _Size, typename _AccLocal>
     _Tp
-    operator()(const _NDItemId __item_id, const _GlobalIdx __global_idx, const _Size __n, _AccLocal& __local_mem) const
+    reduce_impl(const _NDItemId __item_id, const _GlobalIdx __global_idx, const _Size __n, _AccLocal& __local_mem,
+                std::true_type /*has_known_identity*/) const
+    {
+        auto __local_id = __item_id.get_local_id(0);
+        if (__global_idx >= __n)
+        {
+            // Fill the rest of local buffer with init elements so each of inclusive_scan method could correctly work
+            // for each work-item in sub-group
+            __local_mem[__local_id] = __known_identity<_BinaryOperation1, _Tp>;
+        }
+        return __dpl_sycl::__reduce_over_group(__item_id.get_group(), __local_mem[__local_id], __bin_op1);
+    }
+
+    template <typename _NDItemId, typename _GlobalIdx, typename _Size, typename _AccLocal>
+    _Tp
+    reduce_impl(const _NDItemId __item_id, const _GlobalIdx __global_idx, const _Size __n, _AccLocal& __local_mem,
+                std::false_type /*has_known_identity*/) const
     {
         auto __local_idx = __item_id.get_local_id(0);
         auto __group_size = __item_id.get_local_range().size();
@@ -169,6 +279,20 @@ struct reduce
         } while (__k < __group_size);
         return __local_mem[__local_idx];
     }
+
+    template <typename _NDItemId, typename _GlobalIdx, typename _Size, typename _AccLocal>
+    _Tp
+    operator()(const _NDItemId __item_id, const _GlobalIdx __global_idx, const _Size __n, _AccLocal& __local_mem) const
+    {
+        return reduce_impl(__item_id, __global_idx, __n, __local_mem, __has_known_identity<_BinaryOperation1, _Tp>{});
+    }
+
+    template <typename _InitType, typename _Result>
+    void
+    apply_init(const _InitType& __init, _Result&& __result) const
+    {
+        __init_processing<_Tp>{}(__init, __result, __bin_op1);
+    }
 };
 
 // Matchers for early_exit_or and early_exit_find
@@ -312,49 +436,6 @@ struct __scan_no_assign
     }
 };
 
-// types of initial value for parallel_transform_scan
-template <typename _InitType>
-struct __scan_init
-{
-    _InitType __value;
-    using __value_type = _InitType;
-};
-
-template <typename _InitType>
-struct __scan_no_init
-{
-    using __value_type = _InitType;
-};
-
-// structure for the correct processing of the initial scan element
-template <typename _InitType>
-struct __scan_init_processing
-{
-    template <typename _Tp>
-    void
-    operator()(const __scan_init<_InitType>& __init, _Tp&& __value) const
-    {
-        __value = __init.__value;
-    }
-    template <typename _Tp>
-    void
-    operator()(const __scan_no_init<_InitType>&, _Tp&&) const
-    {
-    }
-
-    template <typename _Tp, typename _BinaryOp>
-    void
-    operator()(const __scan_init<_InitType>& __init, _Tp&& __value, _BinaryOp __bin_op) const
-    {
-        __value = __bin_op(__init.__value, __value);
-    }
-    template <typename _Tp, typename _BinaryOp>
-    void
-    operator()(const __scan_no_init<_InitType>&, _Tp&&, _BinaryOp) const
-    {
-    }
-};
-
 // create mask
 template <typename _Pred, typename _Tp>
 struct __create_mask
@@ -466,10 +547,11 @@ struct __partition_by_mask
     }
 };
 
-template <typename _Inclusive, typename _BinaryOp>
+template <typename _Inclusive, typename _BinaryOp, typename _InitType>
 struct __global_scan_functor
 {
     _BinaryOp __binary_op;
+    _InitType __init;
 
     template <typename _Item, typename _OutAcc, typename _InAcc, typename _WgSumsAcc, typename _Size,
               typename _SizePerWg>
@@ -491,6 +573,15 @@ struct __global_scan_functor
             __out_acc[__item_idx] =
                 static_cast<typename __internal::__get_tuple_type<__in_type, __out_type>::__type>(__bin_op_result);
         }
+        __internal::__invoke_if_not(_Inclusive{}, [&]() {
+            //store an initial value to the output first position should be done as postprocess (for in-place scanning)
+            if (__item_idx == 0)
+            {
+                using _Tp = typename _InitType::__value_type;
+                __init_processing<_Tp> __use_init{};
+                __use_init(__init, __out_acc[__item_idx]);
+            }
+        });
     }
 };
 
@@ -498,6 +589,7 @@ template <typename _Inclusive, typename _ExecutionPolicy, typename _BinaryOperat
           typename _WgAssigner, typename _GlobalAssigner, typename _DataAccessor, typename _InitType>
 struct __scan
 {
+    using _Tp = typename _InitType::__value_type;
     _BinaryOperation __bin_op;
     _UnaryOp __unary_op;
     _WgAssigner __wg_assigner;
@@ -506,16 +598,15 @@ struct __scan
 
     template <typename _NDItemId, typename _Size, typename _AccLocal, typename _InAcc, typename _OutAcc,
               typename _WGSumsAcc, typename _SizePerWG, typename _WGSize, typename _ItersPerWG>
-    void operator()(_NDItemId __item, _Size __n, _AccLocal& __local_acc, const _InAcc& __acc, _OutAcc& __out_acc,
-                    _WGSumsAcc& __wg_sums_acc, _SizePerWG __size_per_wg, _WGSize __wgroup_size,
-                    _ItersPerWG __iters_per_wg,
-                    _InitType __init = __scan_no_init<typename _InitType::__value_type>{}) const
+    void
+    scan_impl(_NDItemId __item, _Size __n, _AccLocal& __local_acc, const _InAcc& __acc, _OutAcc& __out_acc,
+              _WGSumsAcc& __wg_sums_acc, _SizePerWG __size_per_wg, _WGSize __wgroup_size, _ItersPerWG __iters_per_wg,
+              _InitType __init, std::false_type /*has_known_identity*/) const
     {
-        using _Tp = typename _InitType::__value_type;
         ::std::size_t __group_id = __item.get_group(0);
         ::std::size_t __global_id = __item.get_global_id(0);
         ::std::size_t __local_id = __item.get_local_id(0);
-        __scan_init_processing<_Tp> __use_init{};
+        __init_processing<_Tp> __use_init{};
 
         ::std::size_t __shift = 0;
         __internal::__invoke_if_not(_Inclusive{}, [&]() { __shift = 1; });
@@ -582,76 +673,25 @@ struct __scan
             if (__adjusted_global_id == __n - 1)
                 __wg_assigner(__wg_sums_acc, __group_id, __local_acc, __local_id);
         }
-        __internal::__invoke_if_not(_Inclusive{}, [&]() {
-            if (__global_id == 0)
-                __use_init(__init, __out_acc[__global_id]);
-        });
 
         if (__local_id == __wgroup_size - 1 && __adjusted_global_id - __wgroup_size < __n)
             __wg_assigner(__wg_sums_acc, __group_id, __local_acc, __local_id);
     }
-};
-
-#if _USE_GROUP_ALGOS
-
-template <typename _Tp, typename = typename ::std::enable_if<::std::is_arithmetic<_Tp>::value, void>::type>
-using __enable_if_arithmetic = _Tp;
-
-template <typename _InitType,
-          typename =
-              typename ::std::enable_if<::std::is_arithmetic<typename _InitType::__value_type>::value, void>::type>
-using __enable_if_arithmetic_init_type = _InitType;
-
-// Reduce on local memory with subgroups
-template <typename _ExecutionPolicy, typename _Tp>
-struct reduce<_ExecutionPolicy, ::std::plus<_Tp>, __enable_if_arithmetic<_Tp>>
-{
-    ::std::plus<_Tp> __reduce;
-
-    template <typename _NDItem, typename _GlobalIdx, typename _GlobalSize, typename _LocalAcc>
-    _Tp
-    operator()(_NDItem __item, _GlobalIdx __global_id, _GlobalSize __n, _LocalAcc __local_mem) const
-    {
-        auto __local_id = __item.get_local_id(0);
-        if (__global_id >= __n)
-        {
-            // Fill the rest of local buffer with 0s so each of inclusive_scan method could correctly work
-            // for each work-item in sub-group
-            __local_mem[__local_id] = 0;
-        }
-        return __dpl_sycl::__reduce_over_group(__item.get_group(), __local_mem[__local_id], __dpl_sycl::__plus<_Tp>());
-    }
-};
-
-template <typename _Inclusive, typename _ExecutionPolicy, typename _UnaryOp, typename _WgAssigner,
-          typename _GlobalAssigner, typename _DataAccessor, typename _InitType>
-struct __scan<_Inclusive, _ExecutionPolicy, ::std::plus<typename _InitType::__value_type>, _UnaryOp, _WgAssigner,
-              _GlobalAssigner, _DataAccessor, __enable_if_arithmetic_init_type<_InitType>>
-{
-    using _Tp = typename _InitType::__value_type;
-    __dpl_sycl::__plus<_Tp> __bin_op;
-    _UnaryOp __unary_op;
-    _WgAssigner __wg_assigner;
-    _GlobalAssigner __gl_assigner;
-    _DataAccessor __data_acc;
 
     template <typename _NDItemId, typename _Size, typename _AccLocal, typename _InAcc, typename _OutAcc,
               typename _WGSumsAcc, typename _SizePerWG, typename _WGSize, typename _ItersPerWG>
-    void operator()(_NDItemId __item, _Size __n, _AccLocal& __local_acc, const _InAcc& __acc, _OutAcc& __out_acc,
-                    const _WGSumsAcc& __wg_sums_acc, _SizePerWG __size_per_wg, _WGSize __wgroup_size,
-                    _ItersPerWG __iters_per_wg, _InitType __init = __scan_no_init<_Tp>{}) const
+    void
+    scan_impl(_NDItemId __item, _Size __n, _AccLocal& __local_acc, const _InAcc& __acc, _OutAcc& __out_acc,
+              _WGSumsAcc& __wg_sums_acc, _SizePerWG __size_per_wg, _WGSize __wgroup_size, _ItersPerWG __iters_per_wg,
+              _InitType __init, std::true_type /*has_known_identity*/) const
     {
         auto __group_id = __item.get_group(0);
         auto __global_id = __item.get_global_id(0);
         auto __local_id = __item.get_local_id(0);
-        auto __use_init = __scan_init_processing<_Tp>{};
+        auto __use_init = __init_processing<_Tp>{};
 
         auto __shift = 0;
-        __internal::__invoke_if_not(_Inclusive{}, [&]() {
-            __shift = 1;
-            if (__global_id == 0)
-                __use_init(__init, __out_acc[__global_id]);
-        });
+        __internal::__invoke_if_not(_Inclusive{}, [&]() { __shift = 1; });
 
         auto __adjusted_global_id = __local_id + __size_per_wg * __group_id;
         auto __adder = __local_acc[0];
@@ -660,7 +700,7 @@ struct __scan<_Inclusive, _ExecutionPolicy, ::std::plus<typename _InitType::__va
             if (__adjusted_global_id < __n)
                 __local_acc[__local_id] = __data_acc(__adjusted_global_id, __acc);
             else
-                __local_acc[__local_id] = _Tp{0}; // for plus only
+                __local_acc[__local_id] = _Tp{__known_identity<_BinaryOperation, _Tp>};
 
             // the result of __unary_op must be convertible to _Tp
             _Tp __old_value = __unary_op(__local_id, __local_acc);
@@ -685,9 +725,18 @@ struct __scan<_Inclusive, _ExecutionPolicy, ::std::plus<typename _InitType::__va
         if (__local_id == __wgroup_size - 1 && __adjusted_global_id - __wgroup_size < __n)
             __wg_assigner(__wg_sums_acc, __group_id, __local_acc, __local_id);
     }
-};
 
-#endif
+    template <typename _NDItemId, typename _Size, typename _AccLocal, typename _InAcc, typename _OutAcc,
+              typename _WGSumsAcc, typename _SizePerWG, typename _WGSize, typename _ItersPerWG>
+    void operator()(_NDItemId __item, _Size __n, _AccLocal& __local_acc, const _InAcc& __acc, _OutAcc& __out_acc,
+                    _WGSumsAcc& __wg_sums_acc, _SizePerWG __size_per_wg, _WGSize __wgroup_size,
+                    _ItersPerWG __iters_per_wg,
+                    _InitType __init = __no_init_value<typename _InitType::__value_type>{}) const
+    {
+        scan_impl(__item, __n, __local_acc, __acc, __out_acc, __wg_sums_acc, __size_per_wg, __wgroup_size,
+                  __iters_per_wg, __init, __has_known_identity<_BinaryOperation, _Tp>{});
+    }
+};
 
 //------------------------------------------------------------------------
 // __brick_includes
