@@ -24,7 +24,7 @@
 #endif
 
 #define ONEDPL_VERSION_MAJOR 2021
-#define ONEDPL_VERSION_MINOR 6
+#define ONEDPL_VERSION_MINOR 7
 #define ONEDPL_VERSION_PATCH 1
 
 #if defined(ONEDPL_USE_DPCPP_BACKEND)
@@ -43,10 +43,10 @@
 #endif
 
 #if defined(ONEDPL_USE_PREDEFINED_POLICIES)
-#    undef _ONEDPL_USE_PREDEFINED_POLICIES
-#    define _ONEDPL_USE_PREDEFINED_POLICIES ONEDPL_USE_DEFAULT_POLICIES
-#elif !defined(_ONEDPL_USE_PREDEFINED_POLICIES)
-#    define _ONEDPL_USE_PREDEFINED_POLICIES 1
+#    undef _ONEDPL_PREDEFINED_POLICIES
+#    define _ONEDPL_PREDEFINED_POLICIES ONEDPL_USE_PREDEFINED_POLICIES
+#elif !defined(_ONEDPL_PREDEFINED_POLICIES)
+#    define _ONEDPL_PREDEFINED_POLICIES 1
 #endif
 
 // macros for deprecation
@@ -319,4 +319,10 @@
 
 #define _ONEDPL_BUILT_IN_STABLE_NAME_PRESENT __has_builtin(__builtin_sycl_unique_stable_name)
 
+// When compile with Intel(R) oneAPI DPC++ Compiler macro is on
+// We need this macro to use compiler specific implementation of SYCL
+#if defined(__INTEL_LLVM_COMPILER) && defined(SYCL_LANGUAGE_VERSION)
+#    define _ONEDPL_SYCL_INTEL_COMPILER 1
+#endif
+
 #endif /* _ONEDPL_CONFIG_H */
