@@ -33,9 +33,10 @@ using namespace TestUtils;
 // WARNING: in the case of using this macro debug output is very large.
 //#define DUMP_CHECK_RESULTS
 
-template <typename BinaryOperation>
-struct test_inclusive_scan_by_segment
+DEFINE_TEST_1(test_inclusive_scan_by_segment, BinaryOperation)
 {
+    DEFINE_TEST_CONSTRUCTOR(test_inclusive_scan_by_segment)
+
     // TODO: replace data generation with random data and update check to compare result to
     // the result of a serial implementation of the algorithm
     template <typename Iterator1, typename Iterator2, typename Iterator3, typename Size>
@@ -120,56 +121,47 @@ struct test_inclusive_scan_by_segment
     operator()(Policy&& exec, Iterator1 keys_first, Iterator1 keys_last, Iterator2 vals_first, Iterator2 vals_last,
                Iterator3 val_res_first, Iterator3 val_res_last, Size n)
     {
+        TestDataTransfer<UDTKind::eKeys, Size> host_keys(*this, n);
+        TestDataTransfer<UDTKind::eVals, Size> host_vals(*this, n);
+        TestDataTransfer<UDTKind::eRes,  Size> host_res (*this, n);
+
         typedef typename ::std::iterator_traits<Iterator1>::value_type KeyT;
 
         // call algorithm with no optional arguments
-        {
-            auto host_keys = get_host_access(keys_first);
-            auto host_vals = get_host_access(vals_first);
-            auto host_val_res = get_host_access(val_res_first);
-
-            initialize_data(host_keys, host_vals, host_val_res, n);
-        }
+        initialize_data(host_keys.get(), host_vals.get(), host_res.get(), n);
+        update_data(host_keys, host_vals, host_res);
 
         auto new_policy = make_new_policy<new_kernel_name<Policy, 0>>(exec);
         auto res1 = oneapi::dpl::inclusive_scan_by_segment(new_policy, keys_first, keys_last, vals_first, val_res_first);
         exec.queue().wait_and_throw();
 
-        {
-            auto host_keys = get_host_access(keys_first);
-            auto host_vals = get_host_access(vals_first);
-            auto host_val_res = get_host_access(val_res_first);
-            check_values(host_keys, host_vals, host_val_res, n);
+        retrieve_data(host_keys, host_vals, host_res);
+        check_values(host_keys.get(), host_vals.get(), host_res.get(), n);
 
-            // call algorithm with equality comparator
-
-            initialize_data(host_keys, host_vals, host_val_res, n);
-        }
+        // call algorithm with equality comparator
+        initialize_data(host_keys.get(), host_vals.get(), host_res.get(), n);
+        update_data(host_keys, host_vals, host_res);
 
         auto new_policy2 = make_new_policy<new_kernel_name<Policy, 1>>(exec);
         auto res2 = oneapi::dpl::inclusive_scan_by_segment(new_policy2, keys_first, keys_last, vals_first, val_res_first,
                                                            [](KeyT first, KeyT second) { return first == second; });
         exec.queue().wait_and_throw();
-        {
-            auto host_keys = get_host_access(keys_first);
-            auto host_vals = get_host_access(vals_first);
-            auto host_val_res = get_host_access(val_res_first);
-            check_values(host_keys, host_vals, host_val_res, n);
 
-            // call algorithm with addition operator
+        retrieve_data(host_keys, host_vals, host_res);
+        check_values(host_keys.get(), host_vals.get(), host_res.get(), n);
 
-            initialize_data(host_keys, host_vals, host_val_res, n);
-        }
+        // call algorithm with equality comparator
+        initialize_data(host_keys.get(), host_vals.get(), host_res.get(), n);
+        update_data(host_keys, host_vals, host_res);
 
         auto new_policy3 = make_new_policy<new_kernel_name<Policy, 2>>(exec);
         auto res3 = oneapi::dpl::inclusive_scan_by_segment(new_policy3, keys_first, keys_last, vals_first, val_res_first,
                                                            [](KeyT first, KeyT second) { return first == second; },
                                                            BinaryOperation());
         exec.queue().wait_and_throw();
-        auto host_keys = get_host_access(keys_first);
-        auto host_vals = get_host_access(vals_first);
-        auto host_val_res = get_host_access(val_res_first);
-        check_values(host_keys, host_vals, host_val_res, n, BinaryOperation());
+
+        retrieve_data(host_keys, host_vals, host_res);
+        check_values(host_keys.get(), host_vals.get(), host_res.get(), n, BinaryOperation());
     }
 #endif
 
@@ -224,15 +216,24 @@ struct UserBinaryOperation
     }
 };
 
-int main() {
+int main()
+{
     {
         using ValueType = ::std::uint64_t;
         using BinaryOperation = ::std::plus<ValueType>;
 
 #if TEST_DPCPP_BACKEND_PRESENT
-        test3buffers<ValueType, test_inclusive_scan_by_segment<BinaryOperation>>();
+        // Run tests for USM shared memory
+        test3buffers<sycl::usm::alloc::shared, test_inclusive_scan_by_segment<ValueType, BinaryOperation>>();
+        // Run tests for USM device memory
+        test3buffers<sycl::usm::alloc::device, test_inclusive_scan_by_segment<ValueType, BinaryOperation>>();
 #endif // TEST_DPCPP_BACKEND_PRESENT
+
+#if TEST_DPCPP_BACKEND_PRESENT
+        test_algo_three_sequences<test_inclusive_scan_by_segment<ValueType, BinaryOperation>>();
+#else
         test_algo_three_sequences<ValueType, test_inclusive_scan_by_segment<BinaryOperation>>();
+#endif // TEST_DPCPP_BACKEND_PRESENT
     }
 
     {
@@ -240,12 +241,20 @@ int main() {
         using BinaryOperation = UserBinaryOperation<ValueType>;
 
 #if TEST_DPCPP_BACKEND_PRESENT
-        test3buffers<ValueType, test_inclusive_scan_by_segment<BinaryOperation>>();
+        // Run tests for USM shared memory
+        test3buffers<sycl::usm::alloc::shared, test_inclusive_scan_by_segment<ValueType, BinaryOperation>>();
+        // Run tests for USM device memory
+        test3buffers<sycl::usm::alloc::device, test_inclusive_scan_by_segment<ValueType, BinaryOperation>>();
 #endif // TEST_DPCPP_BACKEND_PRESENT
 
-#if !_PSTL_ICC_TEST_SIMD_UDS_MACOS_RELEASE_BROKEN
+#if !_PSTL_ICC_TEST_SIMD_UDS_BROKEN
+#if TEST_DPCPP_BACKEND_PRESENT
+        test_algo_three_sequences<test_inclusive_scan_by_segment<ValueType, BinaryOperation>>();
+#else
         test_algo_three_sequences<ValueType, test_inclusive_scan_by_segment<BinaryOperation>>();
-#endif // !_PSTL_ICC_TEST_SIMD_UDS_MACOS_RELEASE_BROKEN
+#endif // TEST_DPCPP_BACKEND_PRESENT
+#endif // !_PSTL_ICC_TEST_SIMD_UDS_BROKEN
+
     }
     return TestUtils::done();
 }
