@@ -369,36 +369,179 @@ main()
     };
 
     sycl::queue queue(sycl::default_selector{}, exception_handler);
-
     std::int32_t err = 0;
 
-    std::cout << "---------------------------------------------------" << std::endl;
-    std::cout << "uniform_int_distribution<std::int32_t>" << std::endl;
-    std::cout << "---------------------------------------------------" << std::endl;
-    err += test<oneapi::dpl::uniform_int_distribution<std::int32_t>>(queue);
-#if TEST_LONG_RUN
-    err += test_vec<oneapi::dpl::uniform_int_distribution<sycl::vec<std::int32_t, 16>>>(queue);
-    err += test_vec<oneapi::dpl::uniform_int_distribution<sycl::vec<std::int32_t, 8>>>(queue);
-    err += test_vec<oneapi::dpl::uniform_int_distribution<sycl::vec<std::int32_t, 4>>>(queue);
-    err += test_vec<oneapi::dpl::uniform_int_distribution<sycl::vec<std::int32_t, 3>>>(queue);
-    err += test_vec<oneapi::dpl::uniform_int_distribution<sycl::vec<std::int32_t, 2>>>(queue);
-    err += test_vec<oneapi::dpl::uniform_int_distribution<sycl::vec<std::int32_t, 1>>>(queue);
-#endif // TEST_LONG_RUN
-    EXPECT_TRUE(!err, "Test FAILED");
+    // Skip tests if DP is not supported
+    if (TestUtils::has_type_support<double>(queue.get_device())) {
 
-    std::cout << "---------------------------------------------------" << std::endl;
-    std::cout << "uniform_int_distribution<std::uint32_t>" << std::endl;
-    std::cout << "---------------------------------------------------" << std::endl;
-    err += test<oneapi::dpl::uniform_int_distribution<std::uint32_t>>(queue);
+        std::cout << "---------------------------------------------------" << std::endl;
+        std::cout << "uniform_int_distribution<std::int32_t>" << std::endl;
+        std::cout << "---------------------------------------------------" << std::endl;
+        err += test<oneapi::dpl::uniform_int_distribution<std::int32_t>>(queue);
 #if TEST_LONG_RUN
-    err += test_vec<oneapi::dpl::uniform_int_distribution<sycl::vec<std::uint32_t, 16>>>(queue);
-    err += test_vec<oneapi::dpl::uniform_int_distribution<sycl::vec<std::uint32_t, 8>>>(queue);
-    err += test_vec<oneapi::dpl::uniform_int_distribution<sycl::vec<std::uint32_t, 4>>>(queue);
-    err += test_vec<oneapi::dpl::uniform_int_distribution<sycl::vec<std::uint32_t, 3>>>(queue);
-    err += test_vec<oneapi::dpl::uniform_int_distribution<sycl::vec<std::uint32_t, 2>>>(queue);
-    err += test_vec<oneapi::dpl::uniform_int_distribution<sycl::vec<std::uint32_t, 1>>>(queue);
+        err += test_vec<oneapi::dpl::uniform_int_distribution<sycl::vec<std::int32_t, 16>>>(queue);
+        err += test_vec<oneapi::dpl::uniform_int_distribution<sycl::vec<std::int32_t, 8>>>(queue);
+        err += test_vec<oneapi::dpl::uniform_int_distribution<sycl::vec<std::int32_t, 4>>>(queue);
+        err += test_vec<oneapi::dpl::uniform_int_distribution<sycl::vec<std::int32_t, 3>>>(queue);
+        err += test_vec<oneapi::dpl::uniform_int_distribution<sycl::vec<std::int32_t, 2>>>(queue);
+        err += test_vec<oneapi::dpl::uniform_int_distribution<sycl::vec<std::int32_t, 1>>>(queue);
 #endif // TEST_LONG_RUN
-    EXPECT_TRUE(!err, "Test FAILED");
+        EXPECT_TRUE(!err, "Test FAILED");
+
+        std::cout << "---------------------------------------------------" << std::endl;
+        std::cout << "uniform_int_distribution<std::uint32_t>" << std::endl;
+        std::cout << "---------------------------------------------------" << std::endl;
+        err += test<oneapi::dpl::uniform_int_distribution<std::uint32_t>>(queue);
+#if TEST_LONG_RUN
+        err += test_vec<oneapi::dpl::uniform_int_distribution<sycl::vec<std::uint32_t, 16>>>(queue);
+        err += test_vec<oneapi::dpl::uniform_int_distribution<sycl::vec<std::uint32_t, 8>>>(queue);
+        err += test_vec<oneapi::dpl::uniform_int_distribution<sycl::vec<std::uint32_t, 4>>>(queue);
+        err += test_vec<oneapi::dpl::uniform_int_distribution<sycl::vec<std::uint32_t, 3>>>(queue);
+        err += test_vec<oneapi::dpl::uniform_int_distribution<sycl::vec<std::uint32_t, 2>>>(queue);
+        err += test_vec<oneapi::dpl::uniform_int_distribution<sycl::vec<std::uint32_t, 1>>>(queue);
+#endif // TEST_LONG_RUN
+        EXPECT_TRUE(!err, "Test FAILED");
+
+        std::cout << "---------------------------------------------------" << std::endl;
+        std::cout << "uniform_real_distribution<double>" << std::endl;
+        std::cout << "---------------------------------------------------" << std::endl;
+        err += test<oneapi::dpl::uniform_real_distribution<double>>(queue);
+#if TEST_LONG_RUN
+        err += test_vec<oneapi::dpl::uniform_real_distribution<sycl::vec<double, 16>>>(queue);
+        err += test_vec<oneapi::dpl::uniform_real_distribution<sycl::vec<double, 8>>>(queue);
+        err += test_vec<oneapi::dpl::uniform_real_distribution<sycl::vec<double, 4>>>(queue);
+        err += test_vec<oneapi::dpl::uniform_real_distribution<sycl::vec<double, 3>>>(queue);
+        err += test_vec<oneapi::dpl::uniform_real_distribution<sycl::vec<double, 2>>>(queue);
+        err += test_vec<oneapi::dpl::uniform_real_distribution<sycl::vec<double, 1>>>(queue);
+#endif // TEST_LONG_RUN
+        EXPECT_TRUE(!err, "Test FAILED");
+
+        std::cout << "---------------------------------------------------" << std::endl;
+        std::cout << "normal_distribution<double>" << std::endl;
+        std::cout << "---------------------------------------------------" << std::endl;
+        err += test<oneapi::dpl::normal_distribution<double>>(queue);
+#if TEST_LONG_RUN
+        err += test_vec<oneapi::dpl::normal_distribution<sycl::vec<double, 16>>>(queue);
+        err += test_vec<oneapi::dpl::normal_distribution<sycl::vec<double, 8>>>(queue);
+        err += test_vec<oneapi::dpl::normal_distribution<sycl::vec<double, 4>>>(queue);
+        err += test_vec<oneapi::dpl::normal_distribution<sycl::vec<double, 3>>>(queue);
+        err += test_vec<oneapi::dpl::normal_distribution<sycl::vec<double, 2>>>(queue);
+        err += test_vec<oneapi::dpl::normal_distribution<sycl::vec<double, 1>>>(queue);
+#endif // TEST_LONG_RUN
+        EXPECT_TRUE(!err, "Test FAILED");
+
+        std::cout << "---------------------------------------------------" << std::endl;
+        std::cout << "exponential_distribution<double>" << std::endl;
+        std::cout << "---------------------------------------------------" << std::endl;
+        err += test<oneapi::dpl::exponential_distribution<double>>(queue);
+#if TEST_LONG_RUN
+        err += test_vec<oneapi::dpl::exponential_distribution<sycl::vec<double, 16>>>(queue);
+        err += test_vec<oneapi::dpl::exponential_distribution<sycl::vec<double, 8>>>(queue);
+        err += test_vec<oneapi::dpl::exponential_distribution<sycl::vec<double, 4>>>(queue);
+        err += test_vec<oneapi::dpl::exponential_distribution<sycl::vec<double, 3>>>(queue);
+        err += test_vec<oneapi::dpl::exponential_distribution<sycl::vec<double, 2>>>(queue);
+        err += test_vec<oneapi::dpl::exponential_distribution<sycl::vec<double, 1>>>(queue);
+#endif // TEST_LONG_RUN
+        EXPECT_TRUE(!err, "Test FAILED");
+
+        std::cout << "---------------------------------------------------" << std::endl;
+        std::cout << "bernoulli_distribution<bool>" << std::endl;
+        std::cout << "---------------------------------------------------" << std::endl;
+        err += test<oneapi::dpl::bernoulli_distribution<bool>>(queue);
+#if TEST_LONG_RUN
+        err += test_vec<oneapi::dpl::bernoulli_distribution<sycl::vec<bool, 16>>>(queue);
+        err += test_vec<oneapi::dpl::bernoulli_distribution<sycl::vec<bool, 8>>>(queue);
+        err += test_vec<oneapi::dpl::bernoulli_distribution<sycl::vec<bool, 4>>>(queue);
+        err += test_vec<oneapi::dpl::bernoulli_distribution<sycl::vec<bool, 3>>>(queue);
+        err += test_vec<oneapi::dpl::bernoulli_distribution<sycl::vec<bool, 2>>>(queue);
+        err += test_vec<oneapi::dpl::bernoulli_distribution<sycl::vec<bool, 1>>>(queue);
+#endif // TEST_LONG_RUN
+        EXPECT_TRUE(!err, "Test FAILED");
+
+        std::cout << "---------------------------------------------------" << std::endl;
+        std::cout << "geometric_distribution<std::int32_t>" << std::endl;
+        std::cout << "---------------------------------------------------" << std::endl;
+        err += test<oneapi::dpl::geometric_distribution<std::int32_t>>(queue);
+#if TEST_LONG_RUN
+        err += test_vec<oneapi::dpl::geometric_distribution<sycl::vec<std::int32_t, 16>>>(queue);
+        err += test_vec<oneapi::dpl::geometric_distribution<sycl::vec<std::int32_t, 8>>>(queue);
+        err += test_vec<oneapi::dpl::geometric_distribution<sycl::vec<std::int32_t, 4>>>(queue);
+        err += test_vec<oneapi::dpl::geometric_distribution<sycl::vec<std::int32_t, 3>>>(queue);
+        err += test_vec<oneapi::dpl::geometric_distribution<sycl::vec<std::int32_t, 2>>>(queue);
+        err += test_vec<oneapi::dpl::geometric_distribution<sycl::vec<std::int32_t, 1>>>(queue);
+#endif // TEST_LONG_RUN
+        EXPECT_TRUE(!err, "Test FAILED");
+
+        std::cout << "---------------------------------------------------" << std::endl;
+        std::cout << "geometric_distribution<std::uint32_t>" << std::endl;
+        std::cout << "---------------------------------------------------" << std::endl;
+        err += test<oneapi::dpl::geometric_distribution<std::uint32_t>>(queue);
+#if TEST_LONG_RUN
+        err += test_vec<oneapi::dpl::geometric_distribution<sycl::vec<std::uint32_t, 16>>>(queue);
+        err += test_vec<oneapi::dpl::geometric_distribution<sycl::vec<std::uint32_t, 8>>>(queue);
+        err += test_vec<oneapi::dpl::geometric_distribution<sycl::vec<std::uint32_t, 4>>>(queue);
+        err += test_vec<oneapi::dpl::geometric_distribution<sycl::vec<std::uint32_t, 3>>>(queue);
+        err += test_vec<oneapi::dpl::geometric_distribution<sycl::vec<std::uint32_t, 2>>>(queue);
+        err += test_vec<oneapi::dpl::geometric_distribution<sycl::vec<std::uint32_t, 1>>>(queue);
+#endif // TEST_LONG_RUN
+        EXPECT_TRUE(!err, "Test FAILED");
+
+        std::cout << "---------------------------------------------------" << std::endl;
+        std::cout << "weibull_distribution<double>" << std::endl;
+        std::cout << "---------------------------------------------------" << std::endl;
+        err += test<oneapi::dpl::weibull_distribution<double>>(queue);
+#if TEST_LONG_RUN
+        err += test_vec<oneapi::dpl::weibull_distribution<sycl::vec<double, 16>>>(queue);
+        err += test_vec<oneapi::dpl::weibull_distribution<sycl::vec<double, 8>>>(queue);
+        err += test_vec<oneapi::dpl::weibull_distribution<sycl::vec<double, 4>>>(queue);
+        err += test_vec<oneapi::dpl::weibull_distribution<sycl::vec<double, 3>>>(queue);
+        err += test_vec<oneapi::dpl::weibull_distribution<sycl::vec<double, 2>>>(queue);
+        err += test_vec<oneapi::dpl::weibull_distribution<sycl::vec<double, 1>>>(queue);
+#endif // TEST_LONG_RUN
+        EXPECT_TRUE(!err, "Test FAILED");
+
+        std::cout << "---------------------------------------------------" << std::endl;
+        std::cout << "lognormal_distribution<double>" << std::endl;
+        std::cout << "---------------------------------------------------" << std::endl;
+        err += test<oneapi::dpl::lognormal_distribution<double>>(queue);
+#if TEST_LONG_RUN
+        err += test_vec<oneapi::dpl::lognormal_distribution<sycl::vec<double, 16>>>(queue);
+        err += test_vec<oneapi::dpl::lognormal_distribution<sycl::vec<double, 8>>>(queue);
+        err += test_vec<oneapi::dpl::lognormal_distribution<sycl::vec<double, 4>>>(queue);
+        err += test_vec<oneapi::dpl::lognormal_distribution<sycl::vec<double, 3>>>(queue);
+        err += test_vec<oneapi::dpl::lognormal_distribution<sycl::vec<double, 2>>>(queue);
+        err += test_vec<oneapi::dpl::lognormal_distribution<sycl::vec<double, 1>>>(queue);
+#endif // TEST_LONG_RUN
+        EXPECT_TRUE(!err, "Test FAILED");
+
+        std::cout << "---------------------------------------------------" << std::endl;
+        std::cout << "cauchy_distribution<double>" << std::endl;
+        std::cout << "---------------------------------------------------" << std::endl;
+        err += test<oneapi::dpl::cauchy_distribution<double>>(queue);
+#if TEST_LONG_RUN
+        err += test_vec<oneapi::dpl::cauchy_distribution<sycl::vec<double, 16>>>(queue);
+        err += test_vec<oneapi::dpl::cauchy_distribution<sycl::vec<double, 8>>>(queue);
+        err += test_vec<oneapi::dpl::cauchy_distribution<sycl::vec<double, 4>>>(queue);
+        err += test_vec<oneapi::dpl::cauchy_distribution<sycl::vec<double, 3>>>(queue);
+        err += test_vec<oneapi::dpl::cauchy_distribution<sycl::vec<double, 2>>>(queue);
+        err += test_vec<oneapi::dpl::cauchy_distribution<sycl::vec<double, 1>>>(queue);
+#endif // TEST_LONG_RUN
+        EXPECT_TRUE(!err, "Test FAILED");
+
+        std::cout << "---------------------------------------------------" << std::endl;
+        std::cout << "extreme_value_distribution<double>" << std::endl;
+        std::cout << "---------------------------------------------------" << std::endl;
+        err += test<oneapi::dpl::extreme_value_distribution<double>>(queue);
+#if TEST_LONG_RUN
+        err += test_vec<oneapi::dpl::extreme_value_distribution<sycl::vec<double, 16>>>(queue);
+        err += test_vec<oneapi::dpl::extreme_value_distribution<sycl::vec<double, 8>>>(queue);
+        err += test_vec<oneapi::dpl::extreme_value_distribution<sycl::vec<double, 4>>>(queue);
+        err += test_vec<oneapi::dpl::extreme_value_distribution<sycl::vec<double, 3>>>(queue);
+        err += test_vec<oneapi::dpl::extreme_value_distribution<sycl::vec<double, 2>>>(queue);
+        err += test_vec<oneapi::dpl::extreme_value_distribution<sycl::vec<double, 1>>>(queue);
+#endif // TEST_LONG_RUN
+        EXPECT_TRUE(!err, "Test FAILED");
+    }
 
     std::cout << "---------------------------------------------------" << std::endl;
     std::cout << "uniform_real_distribution<float>" << std::endl;
@@ -414,20 +557,6 @@ main()
 #endif // TEST_LONG_RUN
     EXPECT_TRUE(!err, "Test FAILED");
 
-    std::cout << "---------------------------------------------------" << std::endl;
-    std::cout << "uniform_real_distribution<double>" << std::endl;
-    std::cout << "---------------------------------------------------" << std::endl;
-    err += test<oneapi::dpl::uniform_real_distribution<double>>(queue);
-#if TEST_LONG_RUN
-    err += test_vec<oneapi::dpl::uniform_real_distribution<sycl::vec<double, 16>>>(queue);
-    err += test_vec<oneapi::dpl::uniform_real_distribution<sycl::vec<double, 8>>>(queue);
-    err += test_vec<oneapi::dpl::uniform_real_distribution<sycl::vec<double, 4>>>(queue);
-    err += test_vec<oneapi::dpl::uniform_real_distribution<sycl::vec<double, 3>>>(queue);
-    err += test_vec<oneapi::dpl::uniform_real_distribution<sycl::vec<double, 2>>>(queue);
-    err += test_vec<oneapi::dpl::uniform_real_distribution<sycl::vec<double, 1>>>(queue);
-#endif // TEST_LONG_RUN
-    EXPECT_TRUE(!err, "Test FAILED");
-
     std::cout << "---------------------------------------------------" << std::endl;
     std::cout << "normal_distribution<float>" << std::endl;
     std::cout << "---------------------------------------------------" << std::endl;
@@ -442,20 +571,6 @@ main()
 #endif // TEST_LONG_RUN
     EXPECT_TRUE(!err, "Test FAILED");
 
-    std::cout << "---------------------------------------------------" << std::endl;
-    std::cout << "normal_distribution<double>" << std::endl;
-    std::cout << "---------------------------------------------------" << std::endl;
-    err += test<oneapi::dpl::normal_distribution<double>>(queue);
-#if TEST_LONG_RUN
-    err += test_vec<oneapi::dpl::normal_distribution<sycl::vec<double, 16>>>(queue);
-    err += test_vec<oneapi::dpl::normal_distribution<sycl::vec<double, 8>>>(queue);
-    err += test_vec<oneapi::dpl::normal_distribution<sycl::vec<double, 4>>>(queue);
-    err += test_vec<oneapi::dpl::normal_distribution<sycl::vec<double, 3>>>(queue);
-    err += test_vec<oneapi::dpl::normal_distribution<sycl::vec<double, 2>>>(queue);
-    err += test_vec<oneapi::dpl::normal_distribution<sycl::vec<double, 1>>>(queue);
-#endif // TEST_LONG_RUN
-    EXPECT_TRUE(!err, "Test FAILED");
-
     std::cout << "---------------------------------------------------" << std::endl;
     std::cout << "exponential_distribution<float>" << std::endl;
     std::cout << "---------------------------------------------------" << std::endl;
@@ -470,62 +585,6 @@ main()
 #endif // TEST_LONG_RUN
     EXPECT_TRUE(!err, "Test FAILED");
 
-    std::cout << "---------------------------------------------------" << std::endl;
-    std::cout << "exponential_distribution<double>" << std::endl;
-    std::cout << "---------------------------------------------------" << std::endl;
-    err += test<oneapi::dpl::exponential_distribution<double>>(queue);
-#if TEST_LONG_RUN
-    err += test_vec<oneapi::dpl::exponential_distribution<sycl::vec<double, 16>>>(queue);
-    err += test_vec<oneapi::dpl::exponential_distribution<sycl::vec<double, 8>>>(queue);
-    err += test_vec<oneapi::dpl::exponential_distribution<sycl::vec<double, 4>>>(queue);
-    err += test_vec<oneapi::dpl::exponential_distribution<sycl::vec<double, 3>>>(queue);
-    err += test_vec<oneapi::dpl::exponential_distribution<sycl::vec<double, 2>>>(queue);
-    err += test_vec<oneapi::dpl::exponential_distribution<sycl::vec<double, 1>>>(queue);
-#endif // TEST_LONG_RUN
-    EXPECT_TRUE(!err, "Test FAILED");
-
-    std::cout << "---------------------------------------------------" << std::endl;
-    std::cout << "bernoulli_distribution<bool>" << std::endl;
-    std::cout << "---------------------------------------------------" << std::endl;
-    err += test<oneapi::dpl::bernoulli_distribution<bool>>(queue);
-#if TEST_LONG_RUN
-    err += test_vec<oneapi::dpl::bernoulli_distribution<sycl::vec<bool, 16>>>(queue);
-    err += test_vec<oneapi::dpl::bernoulli_distribution<sycl::vec<bool, 8>>>(queue);
-    err += test_vec<oneapi::dpl::bernoulli_distribution<sycl::vec<bool, 4>>>(queue);
-    err += test_vec<oneapi::dpl::bernoulli_distribution<sycl::vec<bool, 3>>>(queue);
-    err += test_vec<oneapi::dpl::bernoulli_distribution<sycl::vec<bool, 2>>>(queue);
-    err += test_vec<oneapi::dpl::bernoulli_distribution<sycl::vec<bool, 1>>>(queue);
-#endif // TEST_LONG_RUN
-    EXPECT_TRUE(!err, "Test FAILED");
-
-    std::cout << "---------------------------------------------------" << std::endl;
-    std::cout << "geometric_distribution<std::int32_t>" << std::endl;
-    std::cout << "---------------------------------------------------" << std::endl;
-    err += test<oneapi::dpl::geometric_distribution<std::int32_t>>(queue);
-#if TEST_LONG_RUN
-    err += test_vec<oneapi::dpl::geometric_distribution<sycl::vec<std::int32_t, 16>>>(queue);
-    err += test_vec<oneapi::dpl::geometric_distribution<sycl::vec<std::int32_t, 8>>>(queue);
-    err += test_vec<oneapi::dpl::geometric_distribution<sycl::vec<std::int32_t, 4>>>(queue);
-    err += test_vec<oneapi::dpl::geometric_distribution<sycl::vec<std::int32_t, 3>>>(queue);
-    err += test_vec<oneapi::dpl::geometric_distribution<sycl::vec<std::int32_t, 2>>>(queue);
-    err += test_vec<oneapi::dpl::geometric_distribution<sycl::vec<std::int32_t, 1>>>(queue);
-#endif // TEST_LONG_RUN
-    EXPECT_TRUE(!err, "Test FAILED");
-
-    std::cout << "---------------------------------------------------" << std::endl;
-    std::cout << "geometric_distribution<std::uint32_t>" << std::endl;
-    std::cout << "---------------------------------------------------" << std::endl;
-    err += test<oneapi::dpl::geometric_distribution<std::uint32_t>>(queue);
-#if TEST_LONG_RUN
-    err += test_vec<oneapi::dpl::geometric_distribution<sycl::vec<std::uint32_t, 16>>>(queue);
-    err += test_vec<oneapi::dpl::geometric_distribution<sycl::vec<std::uint32_t, 8>>>(queue);
-    err += test_vec<oneapi::dpl::geometric_distribution<sycl::vec<std::uint32_t, 4>>>(queue);
-    err += test_vec<oneapi::dpl::geometric_distribution<sycl::vec<std::uint32_t, 3>>>(queue);
-    err += test_vec<oneapi::dpl::geometric_distribution<sycl::vec<std::uint32_t, 2>>>(queue);
-    err += test_vec<oneapi::dpl::geometric_distribution<sycl::vec<std::uint32_t, 1>>>(queue);
-#endif // TEST_LONG_RUN
-    EXPECT_TRUE(!err, "Test FAILED");
-
     std::cout << "---------------------------------------------------" << std::endl;
     std::cout << "weibull_distribution<float>" << std::endl;
     std::cout << "---------------------------------------------------" << std::endl;
@@ -540,20 +599,6 @@ main()
 #endif // TEST_LONG_RUN
     EXPECT_TRUE(!err, "Test FAILED");
 
-    std::cout << "---------------------------------------------------" << std::endl;
-    std::cout << "weibull_distribution<double>" << std::endl;
-    std::cout << "---------------------------------------------------" << std::endl;
-    err += test<oneapi::dpl::weibull_distribution<double>>(queue);
-#if TEST_LONG_RUN
-    err += test_vec<oneapi::dpl::weibull_distribution<sycl::vec<double, 16>>>(queue);
-    err += test_vec<oneapi::dpl::weibull_distribution<sycl::vec<double, 8>>>(queue);
-    err += test_vec<oneapi::dpl::weibull_distribution<sycl::vec<double, 4>>>(queue);
-    err += test_vec<oneapi::dpl::weibull_distribution<sycl::vec<double, 3>>>(queue);
-    err += test_vec<oneapi::dpl::weibull_distribution<sycl::vec<double, 2>>>(queue);
-    err += test_vec<oneapi::dpl::weibull_distribution<sycl::vec<double, 1>>>(queue);
-#endif // TEST_LONG_RUN
-    EXPECT_TRUE(!err, "Test FAILED");
-
     std::cout << "---------------------------------------------------" << std::endl;
     std::cout << "lognormal_distribution<float>" << std::endl;
     std::cout << "---------------------------------------------------" << std::endl;
@@ -568,20 +613,6 @@ main()
 #endif // TEST_LONG_RUN
     EXPECT_TRUE(!err, "Test FAILED");
 
-    std::cout << "---------------------------------------------------" << std::endl;
-    std::cout << "lognormal_distribution<double>" << std::endl;
-    std::cout << "---------------------------------------------------" << std::endl;
-    err += test<oneapi::dpl::lognormal_distribution<double>>(queue);
-#if TEST_LONG_RUN
-    err += test_vec<oneapi::dpl::lognormal_distribution<sycl::vec<double, 16>>>(queue);
-    err += test_vec<oneapi::dpl::lognormal_distribution<sycl::vec<double, 8>>>(queue);
-    err += test_vec<oneapi::dpl::lognormal_distribution<sycl::vec<double, 4>>>(queue);
-    err += test_vec<oneapi::dpl::lognormal_distribution<sycl::vec<double, 3>>>(queue);
-    err += test_vec<oneapi::dpl::lognormal_distribution<sycl::vec<double, 2>>>(queue);
-    err += test_vec<oneapi::dpl::lognormal_distribution<sycl::vec<double, 1>>>(queue);
-#endif // TEST_LONG_RUN
-    EXPECT_TRUE(!err, "Test FAILED");
-
     std::cout << "---------------------------------------------------" << std::endl;
     std::cout << "cauchy_distribution<float>" << std::endl;
     std::cout << "---------------------------------------------------" << std::endl;
@@ -596,20 +627,6 @@ main()
 #endif // TEST_LONG_RUN
     EXPECT_TRUE(!err, "Test FAILED");
 
-    std::cout << "---------------------------------------------------" << std::endl;
-    std::cout << "cauchy_distribution<double>" << std::endl;
-    std::cout << "---------------------------------------------------" << std::endl;
-    err += test<oneapi::dpl::cauchy_distribution<double>>(queue);
-#if TEST_LONG_RUN
-    err += test_vec<oneapi::dpl::cauchy_distribution<sycl::vec<double, 16>>>(queue);
-    err += test_vec<oneapi::dpl::cauchy_distribution<sycl::vec<double, 8>>>(queue);
-    err += test_vec<oneapi::dpl::cauchy_distribution<sycl::vec<double, 4>>>(queue);
-    err += test_vec<oneapi::dpl::cauchy_distribution<sycl::vec<double, 3>>>(queue);
-    err += test_vec<oneapi::dpl::cauchy_distribution<sycl::vec<double, 2>>>(queue);
-    err += test_vec<oneapi::dpl::cauchy_distribution<sycl::vec<double, 1>>>(queue);
-#endif // TEST_LONG_RUN
-    EXPECT_TRUE(!err, "Test FAILED");
-
     std::cout << "---------------------------------------------------" << std::endl;
     std::cout << "extreme_value_distribution<float>" << std::endl;
     std::cout << "---------------------------------------------------" << std::endl;
@@ -624,21 +641,6 @@ main()
 #endif // TEST_LONG_RUN
     EXPECT_TRUE(!err, "Test FAILED");
 
-    std::cout << "---------------------------------------------------" << std::endl;
-    std::cout << "extreme_value_distribution<double>" << std::endl;
-    std::cout << "---------------------------------------------------" << std::endl;
-    err += test<oneapi::dpl::extreme_value_distribution<double>>(queue);
-#if TEST_LONG_RUN
-    err += test_vec<oneapi::dpl::extreme_value_distribution<sycl::vec<double, 16>>>(queue);
-    err += test_vec<oneapi::dpl::extreme_value_distribution<sycl::vec<double, 8>>>(queue);
-    err += test_vec<oneapi::dpl::extreme_value_distribution<sycl::vec<double, 4>>>(queue);
-    err += test_vec<oneapi::dpl::extreme_value_distribution<sycl::vec<double, 3>>>(queue);
-    err += test_vec<oneapi::dpl::extreme_value_distribution<sycl::vec<double, 2>>>(queue);
-    err += test_vec<oneapi::dpl::extreme_value_distribution<sycl::vec<double, 1>>>(queue);
-#endif // TEST_LONG_RUN
-    EXPECT_TRUE(!err, "Test FAILED");
-
-
 #endif // TEST_DPCPP_BACKEND_PRESENT && TEST_UNNAMED_LAMBDAS
 
     return TestUtils::done(TEST_DPCPP_BACKEND_PRESENT && TEST_UNNAMED_LAMBDAS);
